@@ -8,8 +8,8 @@ getResidualFunction <- function(residual.function){
 }
 
 getResiduals <- function(model, data=NULL, y = NULL, predict.function=NULL){
-
-  if (!is.null(model$type) && model$type == "classification") {
+  possible_model_type <- try(model$type, silent = TRUE)
+  if (class(possible_model_type) != "try-error" && !is.null(possible_model_type) && possible_model_type == "classification") {
     res <- 1 - predict.function(model, data)[cbind(1:nrow(data),y)]
   } else {
     if(is.factor(y)) y <- as.numeric(y) - 1
