@@ -2,7 +2,7 @@
 #'
 #' @description Mean Square Error.
 #'
-#' @param object An object of class ModelAudit.
+#' @param object An object of class modelAudit or modelResiduals.
 #'
 #' @return an object of class scoreAudit
 #'
@@ -18,7 +18,7 @@
 
 
 scoreMSE <- function(object){
-
+  if(!("modelResiduals" %in% class(object) || "modelAudit" %in% class(object))) stop("The function requires an object created with audit() or modelResiduals().")
 
   MSEResults <- list(
     name = "MSE",
